<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro_RO" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <source>Version %1.%2.%3</source>
        <translation>Versiunea %1.%2.%3</translation>
    </message>
    <message>
        <source>Licensed under the GPLv3</source>
        <translation>Sub licenţa GPLv3</translation>
    </message>
</context>
<context>
    <name>ChatBox</name>
    <message>
        <source>Chat</source>
        <translation>Discută</translation>
    </message>
</context>
<context>
    <name>CreateGameDialog</name>
    <message>
        <source>Create game</source>
        <translation>Creaţi un joc</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Game name</source>
        <translation>Numele jocului</translation>
    </message>
    <message>
        <source>Game type</source>
        <translation>Tipul jocului</translation>
    </message>
    <message>
        <source>Game mode</source>
        <translation>Modul de joc</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>Jucători</translation>
    </message>
    <message>
        <source>Max. Players</source>
        <translation type="obsolete">Nr. max. de jucători</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Pauză</translation>
    </message>
    <message>
        <source>Initial stake</source>
        <translation>Miza iniţială</translation>
    </message>
    <message>
        <source>Blinds</source>
        <translation>Mizele oarbe (Blinds)</translation>
    </message>
    <message>
        <source>Starting blinds</source>
        <translation>Mizele oarbe (Blinds) de început</translation>
    </message>
    <message>
        <source>Raise factor</source>
        <translation>Factorul de plusare</translation>
    </message>
    <message>
        <source>Raise time</source>
        <translation>Timpul de plusare</translation>
    </message>
    <message>
        <source>Max. players</source>
        <translation>Nr. max. de jucători</translation>
    </message>
    <message>
        <source>Private game</source>
        <translation>Joc privat</translation>
    </message>
    <message>
        <source>Password protected</source>
        <translation>Protejat de parolă</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>GameListTableModel</name>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Gametype</source>
        <translation>Tipul de joc</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>Jucători</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Stare</translation>
    </message>
</context>
<context>
    <name>PClient</name>
    <message>
        <source>There is a newer version of HoldingNuts available (at least %1.%2.%3)</source>
        <translation>O nouă versiune a HoldingNuts este disponibilă (cel puţin %1.%2.%3)</translation>
    </message>
    <message>
        <source>The version of this client isn&apos;t compatible anymore with the server. Please download a recent version.</source>
        <translation>Versiunea aceasta nu mai este compatibilă cu serverul nostru. Vă rugăm să descărcaţi o versiune mai nouă.</translation>
    </message>
    <message>
        <source>Game (%1) has been started.</source>
        <translation>Jocul (%1) a început.</translation>
    </message>
    <message>
        <source>Game (%1) has been ended.</source>
        <translation>Jocul (%1) s-a încheiat.</translation>
    </message>
    <message>
        <source>Protocol error. The remote host does not seem to be a HoldingNuts server.</source>
        <translation>Eroare de protocol. Serverul la care încercaţi să vă conectaţi nu pare să aparţină de HoldingNuts.</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectare...</translation>
    </message>
    <message>
        <source>Connection error: %1.</source>
        <translation>Eroare de conectare: %1.</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation>Conectat.</translation>
    </message>
    <message>
        <source>Connection closed.</source>
        <translation>Conexie închisă.</translation>
    </message>
    <message>
        <source>Server running version %1.%2.%3. Your client ID is %4.</source>
        <translation>Serverul rulează versiunea %1.%2.%3. ID-ul dvs. de client este %4.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>The version of the server isn&apos;t compatible anymore with this client version. Please either use an older client version or request the server admin to update the server version.</source>
        <translation>Versiunea serverului nu mai este compatibilă cu această versiune de program. Vă rugă sau să folosiţi o versiune mai veche a programului, sau să cereţi administratorului serverului să-şi actualizeze versiunea.</translation>
    </message>
    <message>
        <source>A new hand (#%1) begins.</source>
        <translation>Începe o nouă mână (nr.%1).</translation>
    </message>
    <message>
        <source>Blinds are now at %1/%2.</source>
        <translation>Mizele oarbe au ajuns acum la %1/%2.</translation>
    </message>
    <message>
        <source>Player %1 broke.</source>
        <translation>Jucătorul %1 e falit.</translation>
    </message>
    <message>
        <source>Your hole cards: [%1 %2].</source>
        <translation>Toate cărţile dvs.: [%1 %2].</translation>
    </message>
    <message>
        <source>The flop: [%1 %2 %3].</source>
        <translation>Flopul (primele 3 cărţi întoarse de dealer): [%1 %2 %3].</translation>
    </message>
    <message>
        <source>The turn: [%1].</source>
        <translation>Rândul: [%1].</translation>
    </message>
    <message>
        <source>The river: [%1].</source>
        <translation>Riverul (ultima carte întoarsă de dealer): [%1].</translation>
    </message>
    <message>
        <source>%1 was folded.</source>
        <translation>%1 a fost scos.</translation>
    </message>
    <message>
        <source>%1 folded.</source>
        <translation>%1 s-a aruncat.</translation>
    </message>
    <message>
        <source>%1 was checked.</source>
        <translation>%1 a fost sărit.</translation>
    </message>
    <message>
        <source>%1 checked.</source>
        <translation>%1 a făcut Pas.</translation>
    </message>
    <message>
        <source>%1 called %2.</source>
        <translation>%1 a egalat pariul lui %2.</translation>
    </message>
    <message>
        <source>%1 bet to %2.</source>
        <translation>%1 pariază la %2.</translation>
    </message>
    <message>
        <source>%1 raised to %2.</source>
        <translation>%1 a plusat la %2.</translation>
    </message>
    <message>
        <source>%1 is allin with %2.</source>
        <translation>%1 a pariat tot, cu %2.</translation>
    </message>
    <message>
        <source>%1 shows %2.</source>
        <translation>%1 arată %2.</translation>
    </message>
    <message>
        <source>%2 (%1) joined foyer.</source>
        <translation>%2 (%1) a intrat în foaier.</translation>
    </message>
    <message>
        <source>%2 (%1) left foyer.</source>
        <translation>%2 (%1) a ieşit din foaier.</translation>
    </message>
    <message>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1, e rândul tău!</translation>
    </message>
    <message>
        <source>%1 wins pot #%2 with %3.</source>
        <translation>%1 câştigă potul nr.%2 cu %3.</translation>
    </message>
    <message>
        <source>%1 receives %3 odd chips of split pot #%2.</source>
        <translation>%1 primeşte %3 cipuri în plus din potul împărţit nr.%2.</translation>
    </message>
</context>
<context>
    <name>PlayerListTableModel</name>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nume</translation>
    </message>
</context>
<context>
    <name>Seat</name>
    <message>
        <source>Location: %1</source>
        <translation>Loc: %1</translation>
    </message>
    <message>
        <source>Name: %1</source>
        <translation>Nume: %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Setări</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Setări generale</translation>
    </message>
    <message>
        <source>Player info</source>
        <translation>Informaţii despre jucător</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aspect</translation>
    </message>
    <message>
        <source>Log to file</source>
        <translation>Înregistrarea informaţiilor jocului</translation>
    </message>
    <message>
        <source>enabled</source>
        <translation>activat</translation>
    </message>
    <message>
        <source>log chat</source>
        <translation>înregistrarea discuţiilor</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Limba</translation>
    </message>
    <message>
        <source>Auto-Detect</source>
        <translation>Auto-detectare</translation>
    </message>
    <message>
        <source>Sounds</source>
        <translation>Sunete</translation>
    </message>
    <message>
        <source>only on focus</source>
        <translation>numai când fereastra jocului e activă</translation>
    </message>
    <message>
        <source>UUID</source>
        <translation>UUID</translation>
    </message>
    <message>
        <source>generate</source>
        <translation>generează</translation>
    </message>
    <message>
        <source>clear</source>
        <translation>şterge</translation>
    </message>
    <message>
        <source>Player name</source>
        <translation>Numele jucătorului</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Loc</translation>
    </message>
    <message>
        <source>Show strength of hand</source>
        <translation>Arată mâna puternică</translation>
    </message>
    <message>
        <source>Card deck</source>
        <translation>Pachetul de cărţi</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Implicit</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Clasic</translation>
    </message>
    <message>
        <source>Log and chat</source>
        <translation>Înregistrare şi discuţii</translation>
    </message>
    <message>
        <source>Centralized table view</source>
        <translation>Vizualizare tabel centralizat</translation>
    </message>
    <message>
        <source>Bring window to top</source>
        <translation>Adu fereastra deasupra</translation>
    </message>
    <message>
        <source>Display time in foyer chat</source>
        <translation>Arată timpul în discuţiile din foaier</translation>
    </message>
    <message>
        <source>Display join/left messages</source>
        <translation>Arată mesajele de alăturare/părăsire (intrare/ieşire)</translation>
    </message>
    <message>
        <source>Display game states</source>
        <translation>Arată starea jocului</translation>
    </message>
    <message>
        <source>Display player chat</source>
        <translation>Arată discuţiile jucătorilor</translation>
    </message>
    <message>
        <source>Display player actions</source>
        <translation>Arată acţiunile jucătorilor</translation>
    </message>
    <message>
        <source>Display hole/community cards</source>
        <translation>Arată toate cărţile/cărţile comune</translation>
    </message>
    <message>
        <source>Foyer chat verbosity</source>
        <translation>Cantitatea de informaţii oferite în timpul discuţiilor din foaier</translation>
    </message>
    <message>
        <source>Table chat verbosity</source>
        <translation>Cantitatea de informaţii oferite în timpul discuţiilor de la masă</translation>
    </message>
</context>
<context>
    <name>WMain</name>
    <message>
        <source>HoldingNuts Foyer</source>
        <translation>Foaierul HoldingNuts</translation>
    </message>
    <message>
        <source>Game name filter:</source>
        <translation type="obsolete">Filtru joc:</translation>
    </message>
    <message>
        <source>&amp;Register</source>
        <translation>În&amp;registrare</translation>
    </message>
    <message>
        <source>&amp;Unregister</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>Game ID</source>
        <translation>ID joc</translation>
    </message>
    <message>
        <source>Initial stakes</source>
        <translation>Mizele iniţiale</translation>
    </message>
    <message>
        <source>Player timeout</source>
        <translation>Pauza jucătorului</translation>
    </message>
    <message>
        <source>Blinds</source>
        <translation>Mize oarbe (Blinds)</translation>
    </message>
    <message>
        <source>The desired server (domain-name or IP) to connect with.
You can optionally specify a port number.
Format: &lt;host&gt;[:&lt;port&gt;]</source>
        <translation>Serverul (numele domeniului sau IP) la care doriţi să vă conectaţi.
Puteţi, opţional, specifica un port.
Format: &lt;host&gt;[:&lt;port&gt;]</translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation>&amp;Conectare</translation>
    </message>
    <message>
        <source>Cl&amp;ose</source>
        <translation>Înc&amp;hide</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>Create own game</source>
        <translation>Creaţi propriul joc</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <source>&amp;Test</source>
        <translation>&amp;Test</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>&amp;Handbook</source>
        <translation>&amp;Manual</translation>
    </message>
    <message>
        <source>CTRL+H</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>CTRL+A</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>Error connecting.</source>
        <translation>Eroare întâlnită în timpul conexiei.</translation>
    </message>
    <message>
        <source>You may need to restart the client for all settings to take effect.</source>
        <translation>E posibil să fie nevoie de repornirea programului, pentru ca toate setările să aibă efect.</translation>
    </message>
    <message>
        <source>THNL</source>
        <translation>THNL</translation>
    </message>
    <message>
        <source>unkown gametype</source>
        <translation>tip de joc necunoscut</translation>
    </message>
    <message>
        <source>Cash game</source>
        <translation>Cash game</translation>
    </message>
    <message>
        <source>Tournament</source>
        <translation>Turneu</translation>
    </message>
    <message>
        <source>Sit&apos;n&apos;Go</source>
        <translation>Sit&apos;n&apos;Go</translation>
    </message>
    <message>
        <source>unkown gamemode</source>
        <translation>mod de joc necunoscut</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation>Aşteptare</translation>
    </message>
    <message>
        <source>Started</source>
        <translation>Început</translation>
    </message>
    <message>
        <source>Ended</source>
        <translation>Încheiat</translation>
    </message>
    <message>
        <source>unkown gamestate</source>
        <translation>stare a jocului necunoscută</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation>Bun venit</translation>
    </message>
    <message>
        <source>offline</source>
        <translation type="obsolete">deconectat</translation>
    </message>
    <message>
        <source>hide started</source>
        <translation>ascunde jocurile începute</translation>
    </message>
    <message>
        <source>hide private</source>
        <translation>ascunde jocurile private</translation>
    </message>
    <message>
        <source>&amp;Open table</source>
        <translation>D&amp;eschide masa</translation>
    </message>
    <message>
        <source>&amp;Start game</source>
        <translation>Î&amp;ncepe jocul</translation>
    </message>
    <message>
        <source>Private game</source>
        <translation>Joc privat</translation>
    </message>
    <message>
        <source>Please enter the game password:</source>
        <translation>Vă rugăm să introduceţi parola jocului:</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Ieşire din cont</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume</translation>
    </message>
    <message>
        <source>Connections</source>
        <translation>Conexiuni</translation>
    </message>
    <message>
        <source>The table will be opened on the next hand.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WTable</name>
    <message>
        <source>&amp;Fold</source>
        <translation>&amp;Aruncare</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>Arată cărţ&amp;ile</translation>
    </message>
    <message>
        <source>&amp;Muck</source>
        <translation>&amp;Renunţare</translation>
    </message>
    <message>
        <source>I&apos;m bac&amp;k</source>
        <translation>M-am în&amp;tors</translation>
    </message>
    <message>
        <source>Sit&amp;out</source>
        <translation>Stai de&amp;oparte</translation>
    </message>
    <message>
        <source>1/4</source>
        <translation>1/4</translation>
    </message>
    <message>
        <source>1/2</source>
        <translation>1/2</translation>
    </message>
    <message>
        <source>3/4</source>
        <translation>3/4</translation>
    </message>
    <message>
        <source>Potsize</source>
        <translation type="obsolete">Mărimea potului</translation>
    </message>
    <message>
        <source>Allin</source>
        <translation>Pariază tot</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>HoldingNuts table</source>
        <translation>Masa HoldingNuts</translation>
    </message>
    <message>
        <source>&amp;Call %1</source>
        <translation>&amp;Egalează pariul (Call) %1</translation>
    </message>
    <message>
        <source>&amp;Raise %1</source>
        <translation>P&amp;lusează %1</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>Pa&amp;s</translation>
    </message>
    <message>
        <source>&amp;Bet %1</source>
        <translation>Paria&amp;ză %1</translation>
    </message>
    <message>
        <source>&amp;Allin %1</source>
        <translation>&amp;Pariază tot %1</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Aruncare</translation>
    </message>
    <message>
        <source>Allin %1</source>
        <translation>Pariază tot %1</translation>
    </message>
    <message>
        <source>Call %1</source>
        <translation>Egalează pariul (Call) %1</translation>
    </message>
    <message>
        <source>Check/Fold</source>
        <translation>Pas/Aruncare</translation>
    </message>
    <message>
        <source>Check</source>
        <translation>Pas</translation>
    </message>
    <message>
        <source>Main pot: %1</source>
        <translation>Pot principal: %1</translation>
    </message>
    <message>
        <source>Side pot %1: %2</source>
        <translation>Pot secundar %1: %2</translation>
    </message>
    <message>
        <source>High Card</source>
        <translation>Cea mai mare carte</translation>
    </message>
    <message>
        <source>One Pair</source>
        <translation>O pereche</translation>
    </message>
    <message>
        <source>Two Pair</source>
        <translation>Două perechi</translation>
    </message>
    <message>
        <source>Three Of A Kind</source>
        <translation>Trei bucăţi</translation>
    </message>
    <message>
        <source>Straight</source>
        <translation>Chintă</translation>
    </message>
    <message>
        <source>Flush</source>
        <translation>Culoare</translation>
    </message>
    <message>
        <source>Full House</source>
        <translation>Full</translation>
    </message>
    <message>
        <source>Four Of A Kind</source>
        <translation>Careu</translation>
    </message>
    <message>
        <source>Royal Flush</source>
        <translation>Chintă roială</translation>
    </message>
    <message>
        <source>Straight Flush</source>
        <translation>Chintă la culoare</translation>
    </message>
    <message>
        <source>Saved screenshot: %1.</source>
        <translation>Imagine salvată: %1.</translation>
    </message>
    <message>
        <source>Unable to save screenshot in %1.</source>
        <translation>Nu s-a putut salva imaginea în %1.</translation>
    </message>
    <message>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <source>Pot</source>
        <translation>Pot</translation>
    </message>
    <message>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1, e rândul tău!</translation>
    </message>
    <message>
        <source>%1, you have %2 seconds left to respond!</source>
        <translation>%1, mai ai %2 secunde pentru a răspunde!</translation>
    </message>
    <message>
        <source>Spades</source>
        <translation>Pică (inimă neagră)</translation>
    </message>
    <message>
        <source>Hearts</source>
        <translation>Cupă (inimă)</translation>
    </message>
    <message>
        <source>Diamonds</source>
        <translation>Caro (romb)</translation>
    </message>
    <message>
        <source>Clubs</source>
        <translation>Treflă</translation>
    </message>
    <message>
        <source>Deuce</source>
        <translation>Doi</translation>
    </message>
    <message>
        <source>Deuces</source>
        <translation>Doiari</translation>
    </message>
    <message>
        <source>Three</source>
        <translation>Trei</translation>
    </message>
    <message>
        <source>Threes</source>
        <translation>Treiari</translation>
    </message>
    <message>
        <source>Four</source>
        <translation>Patru</translation>
    </message>
    <message>
        <source>Fours</source>
        <translation>Pătrari</translation>
    </message>
    <message>
        <source>Five</source>
        <translation>Cinci</translation>
    </message>
    <message>
        <source>Fives</source>
        <translation>Cinciari</translation>
    </message>
    <message>
        <source>Six</source>
        <translation>Şase</translation>
    </message>
    <message>
        <source>Sixes</source>
        <translation>Şesari</translation>
    </message>
    <message>
        <source>Seven</source>
        <translation>Şapte</translation>
    </message>
    <message>
        <source>Sevens</source>
        <translation>Şeptari</translation>
    </message>
    <message>
        <source>Eight</source>
        <translation>Opt</translation>
    </message>
    <message>
        <source>Eights</source>
        <translation>Optari</translation>
    </message>
    <message>
        <source>Nine</source>
        <translation>Nouă</translation>
    </message>
    <message>
        <source>Nines</source>
        <translation>Noiari</translation>
    </message>
    <message>
        <source>Ten</source>
        <translation>Decar</translation>
    </message>
    <message>
        <source>Tens</source>
        <translation>Decari</translation>
    </message>
    <message>
        <source>Jack</source>
        <translation>Valet</translation>
    </message>
    <message>
        <source>Jacks</source>
        <translation>Valeţi</translation>
    </message>
    <message>
        <source>Queen</source>
        <translation>Damă</translation>
    </message>
    <message>
        <source>Queens</source>
        <translation>Dame</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Popă</translation>
    </message>
    <message>
        <source>Kings</source>
        <translation>Popi</translation>
    </message>
    <message>
        <source>Ace</source>
        <translation>As</translation>
    </message>
    <message>
        <source>Aces</source>
        <translation>Aşi</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 şi %2</translation>
    </message>
    <message>
        <source>%1 high</source>
        <translation>mărit cu %1</translation>
    </message>
</context>
</TS>
